@@ -58,12 +58,6 @@ _recon_endpoints = [
     "Preview rules notification count and distribution. This will return aggregations on: channel, count, site.",
     "recon",
     [
-      {
-        "type": "string",
-        "description": "User UUID",
-        "name": "X-CS-USERUUID",
-        "in": "header"
-      },
       {
         "name": "body",
         "in": "body",
@@ -259,12 +253,6 @@ _recon_endpoints = [
     "Get monitoring rules rules by provided IDs.",
     "recon",
     [
-      {
-        "type": "string",
-        "description": "User UUID",
-        "name": "X-CS-USERUUID",
-        "in": "header"
-      },
       {
         "type": "array",
         "items": {
@@ -285,12 +273,6 @@ _recon_endpoints = [
     "Create monitoring rules.",
     "recon",
     [
-      {
-        "type": "string",
-        "description": "User UUID",
-        "name": "X-CS-USERUUID",
-        "in": "header"
-      },
       {
         "name": "body",
         "in": "body",
@@ -305,12 +287,6 @@ _recon_endpoints = [
     "Update monitoring rules.",
     "recon",
     [
-      {
-        "type": "string",
-        "description": "User UUID",
-        "name": "X-CS-USERUUID",
-        "in": "header"
-      },
       {
         "name": "body",
         "in": "body",
@@ -325,12 +301,6 @@ _recon_endpoints = [
     "Delete monitoring rules.",
     "recon",
     [
-      {
-        "type": "string",
-        "description": "User UUID",
-        "name": "X-CS-USERUUID",
-        "in": "header"
-      },
       {
         "type": "array",
         "items": {
@@ -435,20 +405,16 @@ _recon_endpoints = [
     "recon",
     [
       {
-        "type": "string",
-        "description": "User UUID",
-        "name": "X-CS-USERUUID",
-        "in": "header"
-      },
-      {
-        "type": "string",
+        "type": "integer",
         "description": "Starting index of overall result set from which to return ids.",
         "name": "offset",
         "in": "query"
       },
       {
+        "maximum": 500,
+        "minimum": 1,
         "type": "integer",
-        "description": "Number of ids to return.",
+        "description": "Number of IDs to return. Offset + limit should NOT be above 10K.",
         "name": "limit",
         "in": "query"
       },
